# tensorflow-qndex

[![PyPI version](https://badge.fury.io/py/tensorflow-qndex.svg)](https://badge.fury.io/py/tensorflow-qndex)
[![Python versions](https://img.shields.io/pypi/pyversions/tensorflow-qndex.svg)](setup.py)
[![Build Status](https://travis-ci.org/raviqqe/tensorflow-qndex.svg?branch=master)](https://travis-ci.org/raviqqe/tensorflow-qndex)
[![License](https://img.shields.io/badge/license-unlicense-lightgray.svg)](https://unlicense.org)

[tensorflow-qnd](https://github.com/raviqqe/tensorflow-qnd)
x
[tensorflow-extenteten](https://github.com/raviqqe/tensorflow-extenteten)


## License

[The Unlicense](https://unlicense.org)
